==> haskell-shellmet-0.0.5.0-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shellmet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shellmet
version:              0.0.5.0
visibility:           public
id:                   shellmet-0.0.5.0-4WbRf1cgcye6zNZ8mc66qf
key:                  shellmet-0.0.5.0-4WbRf1cgcye6zNZ8mc66qf
license:              MPL-2.0
copyright:            2019-2022 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov
homepage:             https://github.com/kowainik/shellmet
synopsis:             Out of the shell solution for scripting in Haskell
description:
    Shellmet provides easy and convenient way to call shell commands from Haskell programs

category:             Shell, Command Line
abi:                  cd5f58d7d65ede7bdfcc1df3ad0376fc
exposed:              True
exposed-modules:      Shellmet
import-dirs:          /usr/lib/ghc-9.4.8/site-local/shellmet-0.0.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/shellmet-0.0.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/shellmet-0.0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shellmet
hs-libraries:         HSshellmet-0.0.5.0-4WbRf1cgcye6zNZ8mc66qf
depends:              base-4.17.2.1 process-1.6.18.0 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-shellmet/html/shellmet.haddock
haddock-html:         /usr/share/doc/haskell-shellmet/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shellmet-0.0.5.0-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shellmet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shellmet
version:              0.0.5.0
visibility:           public
id:                   shellmet-0.0.5.0-8PFg8K3bg6lL15cl98znqV
key:                  shellmet-0.0.5.0-8PFg8K3bg6lL15cl98znqV
license:              MPL-2.0
copyright:            2019-2022 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov
homepage:             https://github.com/kowainik/shellmet
synopsis:             Out of the shell solution for scripting in Haskell
description:
    Shellmet provides easy and convenient way to call shell commands from Haskell programs

category:             Shell, Command Line
abi:                  ab9a7432ed9520b4d212b24ee33ad872
exposed:              True
exposed-modules:      Shellmet
import-dirs:          /usr/lib/ghc-9.4.8/site-local/shellmet-0.0.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/shellmet-0.0.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/shellmet-0.0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shellmet
hs-libraries:         HSshellmet-0.0.5.0-8PFg8K3bg6lL15cl98znqV
depends:              base-4.17.2.1 process-1.6.18.0 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-shellmet/html/shellmet.haddock
haddock-html:         /usr/share/doc/haskell-shellmet/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
